==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/compute/kotlin/inputs/ImageOSDiskArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.compute.kotlin.inputs

import com.pulumi.azurenative.compute.inputs.ImageOSDiskArgs.builder
import com.pulumi.azurenative.compute.kotlin.enums.CachingTypes
import com.pulumi.azurenative.compute.kotlin.enums.OperatingSystemStateTypes
import com.pulumi.azurenative.compute.kotlin.enums.OperatingSystemTypes
import com.pulumi.azurenative.compute.kotlin.enums.StorageAccountTypes
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Describes an Operating System disk.
 * @property blobUri The Virtual Hard Disk.
 * @property caching Specifies the caching requirements. Possible values are: **None,** **ReadOnly,** **ReadWrite.** The default values are: **None for Standard storage. ReadOnly for Premium storage.**
 * @property diskEncryptionSet Specifies the customer managed disk encryption set resource id for the managed image disk.
 * @property diskSizeGB Specifies the size of empty data disks in gigabytes. This element can be used to overwrite the name of the disk in a virtual machine image. This value cannot be larger than 1023 GB.
 * @property managedDisk The managedDisk.
 * @property osState The OS State. For managed images, use Generalized.
 * @property osType This property allows you to specify the type of the OS that is included in the disk if creating a VM from a custom image. Possible values are: **Windows,** **Linux.**
 * @property snapshot The snapshot.
 * @property storageAccountType Specifies the storage account type for the managed disk. NOTE: UltraSSD_LRS can only be used with data disks, it cannot be used with OS Disk.
 */
public data class ImageOSDiskArgs(
    public val blobUri: Output<String>? = null,
    public val caching: Output<CachingTypes>? = null,
    public val diskEncryptionSet: Output<DiskEncryptionSetParametersArgs>? = null,
    public val diskSizeGB: Output<Int>? = null,
    public val managedDisk: Output<SubResourceArgs>? = null,
    public val osState: Output<OperatingSystemStateTypes>,
    public val osType: Output<OperatingSystemTypes>,
    public val snapshot: Output<SubResourceArgs>? = null,
    public val storageAccountType: Output<Either<String, StorageAccountTypes>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.compute.inputs.ImageOSDiskArgs> {
    override fun toJava(): com.pulumi.azurenative.compute.inputs.ImageOSDiskArgs =
        com.pulumi.azurenative.compute.inputs.ImageOSDiskArgs.builder()
            .blobUri(blobUri?.applyValue({ args0 -> args0 }))
            .caching(caching?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .diskEncryptionSet(diskEncryptionSet?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .diskSizeGB(diskSizeGB?.applyValue({ args0 -> args0 }))
            .managedDisk(managedDisk?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .osState(osState.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .osType(osType.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .snapshot(snapshot?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .storageAccountType(
                storageAccountType?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            ).build()
}

/**
 * Builder for [ImageOSDiskArgs].
 */
@PulumiTagMarker
public class ImageOSDiskArgsBuilder internal constructor() {
    private var blobUri: Output<String>? = null

    private var caching: Output<CachingTypes>? = null

    private var diskEncryptionSet: Output<DiskEncryptionSetParametersArgs>? = null

    private var diskSizeGB: Output<Int>? = null

    private var managedDisk: Output<SubResourceArgs>? = null

    private var osState: Output<OperatingSystemStateTypes>? = null

    private var osType: Output<OperatingSystemTypes>? = null

    private var snapshot: Output<SubResourceArgs>? = null

    private var storageAccountType: Output<Either<String, StorageAccountTypes>>? = null

    /**
     * @param value The Virtual Hard Disk.
     */
    @JvmName("npjjuietlpcdwjcj")
    public suspend fun blobUri(`value`: Output<String>) {
        this.blobUri = value
    }

    /**
     * @param value Specifies the caching requirements. Possible values are: **None,** **ReadOnly,** **ReadWrite.** The default values are: **None for Standard storage. ReadOnly for Premium storage.**
     */
    @JvmName("xiccdwuyjioeyots")
    public suspend fun caching(`value`: Output<CachingTypes>) {
        this.caching = value
    }

    /**
     * @param value Specifies the customer managed disk encryption set resource id for the managed image disk.
     */
    @JvmName("drwxqaacxesipphn")
    public suspend fun diskEncryptionSet(`value`: Output<DiskEncryptionSetParametersArgs>) {
        this.diskEncryptionSet = value
    }

    /**
     * @param value Specifies the size of empty data disks in gigabytes. This element can be used to overwrite the name of the disk in a virtual machine image. This value cannot be larger than 1023 GB.
     */
    @JvmName("owqmhfhdjbquobkw")
    public suspend fun diskSizeGB(`value`: Output<Int>) {
        this.diskSizeGB = value
    }

    /**
     * @param value The managedDisk.
     */
    @JvmName("yuwkpuerbiexdmti")
    public suspend fun managedDisk(`value`: Output<SubResourceArgs>) {
        this.managedDisk = value
    }

    /**
     * @param value The OS State. For managed images, use Generalized.
     */
    @JvmName("koemoylruyvmqfoe")
    public suspend fun osState(`value`: Output<OperatingSystemStateTypes>) {
        this.osState = value
    }

    /**
     * @param value This property allows you to specify the type of the OS that is included in the disk if creating a VM from a custom image. Possible values are: **Windows,** **Linux.**
     */
    @JvmName("pxbnkcjdcygofuum")
    public suspend fun osType(`value`: Output<OperatingSystemTypes>) {
        this.osType = value
    }

    /**
     * @param value The snapshot.
     */
    @JvmName("yhdngigcmanetlws")
    public suspend fun snapshot(`value`: Output<SubResourceArgs>) {
        this.snapshot = value
    }

    /**
     * @param value Specifies the storage account type for the managed disk. NOTE: UltraSSD_LRS can only be used with data disks, it cannot be used with OS Disk.
     */
    @JvmName("mbvnkkpwuvgmfbyr")
    public suspend fun storageAccountType(`value`: Output<Either<String, StorageAccountTypes>>) {
        this.storageAccountType = value
    }

    /**
     * @param value The Virtual Hard Disk.
     */
    @JvmName("uchcgsnpgqbidngr")
    public suspend fun blobUri(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.blobUri = mapped
    }

    /**
     * @param value Specifies the caching requirements. Possible values are: **None,** **ReadOnly,** **ReadWrite.** The default values are: **None for Standard storage. ReadOnly for Premium storage.**
     */
    @JvmName("ijlwfwxrptmrntuy")
    public suspend fun caching(`value`: CachingTypes?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.caching = mapped
    }

    /**
     * @param value Specifies the customer managed disk encryption set resource id for the managed image disk.
     */
    @JvmName("pyanrlqagpmaahjp")
    public suspend fun diskEncryptionSet(`value`: DiskEncryptionSetParametersArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.diskEncryptionSet = mapped
    }

    /**
     * @param argument Specifies the customer managed disk encryption set resource id for the managed image disk.
     */
    @JvmName("fxatpakiojqhqjtf")
    public suspend
    fun diskEncryptionSet(argument: suspend DiskEncryptionSetParametersArgsBuilder.() -> Unit) {
        val toBeMapped = DiskEncryptionSetParametersArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.diskEncryptionSet = mapped
    }

    /**
     * @param value Specifies the size of empty data disks in gigabytes. This element can be used to overwrite the name of the disk in a virtual machine image. This value cannot be larger than 1023 GB.
     */
    @JvmName("ipdsovjqnxgaawqq")
    public suspend fun diskSizeGB(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.diskSizeGB = mapped
    }

    /**
     * @param value The managedDisk.
     */
    @JvmName("ifhjdjdnvdphiusx")
    public suspend fun managedDisk(`value`: SubResourceArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.managedDisk = mapped
    }

    /**
     * @param argument The managedDisk.
     */
    @JvmName("kkxodufkscxjpcrn")
    public suspend fun managedDisk(argument: suspend SubResourceArgsBuilder.() -> Unit) {
        val toBeMapped = SubResourceArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.managedDisk = mapped
    }

    /**
     * @param value The OS State. For managed images, use Generalized.
     */
    @JvmName("iamvckpwdrslwity")
    public suspend fun osState(`value`: OperatingSystemStateTypes) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.osState = mapped
    }

    /**
     * @param value This property allows you to specify the type of the OS that is included in the disk if creating a VM from a custom image. Possible values are: **Windows,** **Linux.**
     */
    @JvmName("syltgpyjkwxxkdlr")
    public suspend fun osType(`value`: OperatingSystemTypes) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.osType = mapped
    }

    /**
     * @param value The snapshot.
     */
    @JvmName("aajxruoqmryhjfns")
    public suspend fun snapshot(`value`: SubResourceArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.snapshot = mapped
    }

    /**
     * @param argument The snapshot.
     */
    @JvmName("ivmokcrokggmkwku")
    public suspend fun snapshot(argument: suspend SubResourceArgsBuilder.() -> Unit) {
        val toBeMapped = SubResourceArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.snapshot = mapped
    }

    /**
     * @param value Specifies the storage account type for the managed disk. NOTE: UltraSSD_LRS can only be used with data disks, it cannot be used with OS Disk.
     */
    @JvmName("ycvhustkdahugmim")
    public suspend fun storageAccountType(`value`: Either<String, StorageAccountTypes>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.storageAccountType = mapped
    }

    /**
     * @param value Specifies the storage account type for the managed disk. NOTE: UltraSSD_LRS can only be used with data disks, it cannot be used with OS Disk.
     */
    @JvmName("vdmswfubyhhtrpuf")
    public fun storageAccountType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, StorageAccountTypes>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.storageAccountType = mapped
    }

    /**
     * @param value Specifies the storage account type for the managed disk. NOTE: UltraSSD_LRS can only be used with data disks, it cannot be used with OS Disk.
     */
    @JvmName("nnroqpkavhhqdvop")
    public fun storageAccountType(`value`: StorageAccountTypes) {
        val toBeMapped = Either.ofRight<String, StorageAccountTypes>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.storageAccountType = mapped
    }

    internal fun build(): ImageOSDiskArgs = ImageOSDiskArgs(
        blobUri = blobUri,
        caching = caching,
        diskEncryptionSet = diskEncryptionSet,
        diskSizeGB = diskSizeGB,
        managedDisk = managedDisk,
        osState = osState ?: throw PulumiNullFieldException("osState"),
        osType = osType ?: throw PulumiNullFieldException("osType"),
        snapshot = snapshot,
        storageAccountType = storageAccountType,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/compute/kotlin/inputs/ImageOSDiskArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.compute.kotlin.inputs

import com.pulumi.azurenative.compute.inputs.ImageOSDiskArgs.builder
import com.pulumi.azurenative.compute.kotlin.enums.CachingTypes
import com.pulumi.azurenative.compute.kotlin.enums.OperatingSystemStateTypes
import com.pulumi.azurenative.compute.kotlin.enums.OperatingSystemTypes
import com.pulumi.azurenative.compute.kotlin.enums.StorageAccountTypes
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Describes an Operating System disk.
 * @property blobUri The Virtual Hard Disk.
 * @property caching Specifies the caching requirements. Possible values are: **None,** **ReadOnly,** **ReadWrite.** The default values are: **None for Standard storage. ReadOnly for Premium storage.**
 * @property diskEncryptionSet Specifies the customer managed disk encryption set resource id for the managed image disk.
 * @property diskSizeGB Specifies the size of empty data disks in gigabytes. This element can be used to overwrite the name of the disk in a virtual machine image. This value cannot be larger than 1023 GB.
 * @property managedDisk The managedDisk.
 * @property osState The OS State. For managed images, use Generalized.
 * @property osType This property allows you to specify the type of the OS that is included in the disk if creating a VM from a custom image. Possible values are: **Windows,** **Linux.**
 * @property snapshot The snapshot.
 * @property storageAccountType Specifies the storage account type for the managed disk. NOTE: UltraSSD_LRS can only be used with data disks, it cannot be used with OS Disk.
 */
public data class ImageOSDiskArgs(
    public val blobUri: Output<String>? = null,
    public val caching: Output<CachingTypes>? = null,
    public val diskEncryptionSet: Output<DiskEncryptionSetParametersArgs>? = null,
    public val diskSizeGB: Output<Int>? = null,
    public val managedDisk: Output<SubResourceArgs>? = null,
    public val osState: Output<OperatingSystemStateTypes>,
    public val osType: Output<OperatingSystemTypes>,
    public val snapshot: Output<SubResourceArgs>? = null,
    public val storageAccountType: Output<Either<String, StorageAccountTypes>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.compute.inputs.ImageOSDiskArgs> {
    override fun toJava(): com.pulumi.azurenative.compute.inputs.ImageOSDiskArgs =
        com.pulumi.azurenative.compute.inputs.ImageOSDiskArgs.builder()
            .blobUri(blobUri?.applyValue({ args0 -> args0 }))
            .caching(caching?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .diskEncryptionSet(diskEncryptionSet?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .diskSizeGB(diskSizeGB?.applyValue({ args0 -> args0 }))
            .managedDisk(managedDisk?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .osState(osState.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .osType(osType.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .snapshot(snapshot?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .storageAccountType(
                storageAccountType?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            ).build()
}

/**
 * Builder for [ImageOSDiskArgs].
 */
@PulumiTagMarker
public class ImageOSDiskArgsBuilder internal constructor() {
    private var blobUri: Output<String>? = null

    private var caching: Output<CachingTypes>? = null

    private var diskEncryptionSet: Output<DiskEncryptionSetParametersArgs>? = null

    private var diskSizeGB: Output<Int>? = null

    private var managedDisk: Output<SubResourceArgs>? = null

    private var osState: Output<OperatingSystemStateTypes>? = null

    private var osType: Output<OperatingSystemTypes>? = null

    private var snapshot: Output<SubResourceArgs>? = null

    private var storageAccountType: Output<Either<String, StorageAccountTypes>>? = null

    /**
     * @param value The Virtual Hard Disk.
     */
    @JvmName("odfxbmmlstmnjatn")
    public suspend fun blobUri(`value`: Output<String>) {
        this.blobUri = value
    }

    /**
     * @param value Specifies the caching requirements. Possible values are: **None,** **ReadOnly,** **ReadWrite.** The default values are: **None for Standard storage. ReadOnly for Premium storage.**
     */
    @JvmName("jrwofjtfqpkerakl")
    public suspend fun caching(`value`: Output<CachingTypes>) {
        this.caching = value
    }

    /**
     * @param value Specifies the customer managed disk encryption set resource id for the managed image disk.
     */
    @JvmName("detbkdodykbgdkms")
    public suspend fun diskEncryptionSet(`value`: Output<DiskEncryptionSetParametersArgs>) {
        this.diskEncryptionSet = value
    }

    /**
     * @param value Specifies the size of empty data disks in gigabytes. This element can be used to overwrite the name of the disk in a virtual machine image. This value cannot be larger than 1023 GB.
     */
    @JvmName("hjksfgbmfbbrbirs")
    public suspend fun diskSizeGB(`value`: Output<Int>) {
        this.diskSizeGB = value
    }

    /**
     * @param value The managedDisk.
     */
    @JvmName("pehpbvndymyunjlw")
    public suspend fun managedDisk(`value`: Output<SubResourceArgs>) {
        this.managedDisk = value
    }

    /**
     * @param value The OS State. For managed images, use Generalized.
     */
    @JvmName("asdrwscbewcpxgld")
    public suspend fun osState(`value`: Output<OperatingSystemStateTypes>) {
        this.osState = value
    }

    /**
     * @param value This property allows you to specify the type of the OS that is included in the disk if creating a VM from a custom image. Possible values are: **Windows,** **Linux.**
     */
    @JvmName("wmgsylqwsscrybri")
    public suspend fun osType(`value`: Output<OperatingSystemTypes>) {
        this.osType = value
    }

    /**
     * @param value The snapshot.
     */
    @JvmName("yrrjlslbnuoqoeoa")
    public suspend fun snapshot(`value`: Output<SubResourceArgs>) {
        this.snapshot = value
    }

    /**
     * @param value Specifies the storage account type for the managed disk. NOTE: UltraSSD_LRS can only be used with data disks, it cannot be used with OS Disk.
     */
    @JvmName("ttmyvnbqjctrpbnt")
    public suspend fun storageAccountType(`value`: Output<Either<String, StorageAccountTypes>>) {
        this.storageAccountType = value
    }

    /**
     * @param value The Virtual Hard Disk.
     */
    @JvmName("nhuyjefrmxwblfny")
    public suspend fun blobUri(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.blobUri = mapped
    }

    /**
     * @param value Specifies the caching requirements. Possible values are: **None,** **ReadOnly,** **ReadWrite.** The default values are: **None for Standard storage. ReadOnly for Premium storage.**
     */
    @JvmName("ekmpnvrcaufudxxl")
    public suspend fun caching(`value`: CachingTypes?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.caching = mapped
    }

    /**
     * @param value Specifies the customer managed disk encryption set resource id for the managed image disk.
     */
    @JvmName("ewiuxreoavrhhpfu")
    public suspend fun diskEncryptionSet(`value`: DiskEncryptionSetParametersArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.diskEncryptionSet = mapped
    }

    /**
     * @param argument Specifies the customer managed disk encryption set resource id for the managed image disk.
     */
    @JvmName("mvlscsxnhdyljakl")
    public suspend
    fun diskEncryptionSet(argument: suspend DiskEncryptionSetParametersArgsBuilder.() -> Unit) {
        val toBeMapped = DiskEncryptionSetParametersArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.diskEncryptionSet = mapped
    }

    /**
     * @param value Specifies the size of empty data disks in gigabytes. This element can be used to overwrite the name of the disk in a virtual machine image. This value cannot be larger than 1023 GB.
     */
    @JvmName("olwgydtdqqdqmket")
    public suspend fun diskSizeGB(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.diskSizeGB = mapped
    }

    /**
     * @param value The managedDisk.
     */
    @JvmName("ouuajdeqtwpogrmb")
    public suspend fun managedDisk(`value`: SubResourceArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.managedDisk = mapped
    }

    /**
     * @param argument The managedDisk.
     */
    @JvmName("lobmiljmwrjaeeas")
    public suspend fun managedDisk(argument: suspend SubResourceArgsBuilder.() -> Unit) {
        val toBeMapped = SubResourceArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.managedDisk = mapped
    }

    /**
     * @param value The OS State. For managed images, use Generalized.
     */
    @JvmName("hakcbanodqelsddf")
    public suspend fun osState(`value`: OperatingSystemStateTypes) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.osState = mapped
    }

    /**
     * @param value This property allows you to specify the type of the OS that is included in the disk if creating a VM from a custom image. Possible values are: **Windows,** **Linux.**
     */
    @JvmName("mwnpgqijlursqtib")
    public suspend fun osType(`value`: OperatingSystemTypes) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.osType = mapped
    }

    /**
     * @param value The snapshot.
     */
    @JvmName("akwimiedslqklxwh")
    public suspend fun snapshot(`value`: SubResourceArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.snapshot = mapped
    }

    /**
     * @param argument The snapshot.
     */
    @JvmName("cphsmghasydxamjb")
    public suspend fun snapshot(argument: suspend SubResourceArgsBuilder.() -> Unit) {
        val toBeMapped = SubResourceArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.snapshot = mapped
    }

    /**
     * @param value Specifies the storage account type for the managed disk. NOTE: UltraSSD_LRS can only be used with data disks, it cannot be used with OS Disk.
     */
    @JvmName("iwvirnrafpundeck")
    public suspend fun storageAccountType(`value`: Either<String, StorageAccountTypes>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.storageAccountType = mapped
    }

    /**
     * @param value Specifies the storage account type for the managed disk. NOTE: UltraSSD_LRS can only be used with data disks, it cannot be used with OS Disk.
     */
    @JvmName("aeclmfjomapjmuah")
    public fun storageAccountType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, StorageAccountTypes>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.storageAccountType = mapped
    }

    /**
     * @param value Specifies the storage account type for the managed disk. NOTE: UltraSSD_LRS can only be used with data disks, it cannot be used with OS Disk.
     */
    @JvmName("qapcohwoxjvpqfhq")
    public fun storageAccountType(`value`: StorageAccountTypes) {
        val toBeMapped = Either.ofRight<String, StorageAccountTypes>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.storageAccountType = mapped
    }

    internal fun build(): ImageOSDiskArgs = ImageOSDiskArgs(
        blobUri = blobUri,
        caching = caching,
        diskEncryptionSet = diskEncryptionSet,
        diskSizeGB = diskSizeGB,
        managedDisk = managedDisk,
        osState = osState ?: throw PulumiNullFieldException("osState"),
        osType = osType ?: throw PulumiNullFieldException("osType"),
        snapshot = snapshot,
        storageAccountType = storageAccountType,
    )
}
